import React from 'react';
import { mount, shallow, ReactWrapper } from 'enzyme';
import AutoSizer from 'react-virtualized-auto-sizer';
import { Graph } from '@grafana/ui';
import { DashboardModel } from 'app/features/dashboard/state';
import AnalyticsStatsTab, { Props } from './AnalyticsStatsTab';
import { getMockDailySummaries } from '../__mocks__/dailySummariesMocks';

const setup = async (props: Props): Promise<ReactWrapper> => {
  let wrapper = await mount(<AnalyticsStatsTab {...props} />);
  wrapper.update();
  return wrapper;
};

describe('Render', () => {
  it('should render empty component - no data', async () => {
    const props: Props = {
      dashboard: new DashboardModel({ id: 1 }),
      dailySummaries: [],
      theme: null,
    };
    const wrapper = await setup(props);

    expect(wrapper.exists(AutoSizer)).toEqual(false);
    expect(wrapper.children().text()).toEqual('No data.');
  });

  it('should render query and error counts from daily summaries', async () => {
    const props: Props = {
      dashboard: new DashboardModel({ id: 1 }),
      dailySummaries: getMockDailySummaries(),
      theme: null,
    };
    const wrapper = await setup(props);

    expect(wrapper.exists(AutoSizer)).toEqual(true);
    const autoSizer = await shallow(
      wrapper
        .find(AutoSizer)
        .props()
        .children({ width: 100, height: 100 }) as React.ReactElement
    );

    expect(autoSizer.find(Graph)).toHaveLength(2);
  });
});
